@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Protocol::ACME - Interface to the Let's Encrypt ACME API
 
 =head1 VERSION
 
-Version 0.11
+Version 0.15
 
 =head1 SYNOPSIS
 
@@ -788,10 +788,12 @@ sub check_challenge
       sleep(2);
       $resp = $self->_request_get( $status_url );
     }
-    elsif ( $self->{content}{status} eq "invalid" ) {
+    elsif ( $self->{content}{status} eq "invalid" )
+    {
       _throw(%{ $self->{content} });
-    } 
-    else {
+    }
+    else
+    {
       last;
     }
   }
@@ -1116,7 +1118,7 @@ copy of the full license at:
 L<http://www.perlfoundation.org/artistic_license_2_0>
 
 Any use, modification, and distribution of the Standard or Modified
-Version 0.11
+Version 0.15
 distributing the Package, you accept this license. Do not use, modify,
 or distribute the Package, if you do not accept this license.
 
